@@ -2,7 +2,6 @@ package main
 
 import (
 	"github.com/hashicorp/packer/command"
-	"github.com/hashicorp/packer/version"
 	"github.com/mitchellh/cli"
 )
 
@@ -19,7 +18,10 @@ const OutputPrefix = "o:"
 func init() {
 	Commands = map[string]cli.CommandFactory{
 		"build": func() (cli.Command, error) {
-			return &command.BuildCommand{
+			return &command.BuildCommand{Meta: *CommandMeta}, nil
+		},
+		"console": func() (cli.Command, error) {
+			return &command.ConsoleCommand{
 				Meta: *CommandMeta,
 			}, nil
 		},
@@ -30,14 +32,32 @@ func init() {
 			}, nil
 		},
 
+		"fmt": func() (cli.Command, error) {
+			return &command.FormatCommand{
+				Meta: *CommandMeta,
+			}, nil
+		},
+
+		"hcl2_upgrade": func() (cli.Command, error) {
+			return &command.HCL2UpgradeCommand{
+				Meta: *CommandMeta,
+			}, nil
+		},
+
+		"init": func() (cli.Command, error) {
+			return &command.InitCommand{
+				Meta: *CommandMeta,
+			}, nil
+		},
+
 		"inspect": func() (cli.Command, error) {
 			return &command.InspectCommand{
 				Meta: *CommandMeta,
 			}, nil
 		},
 
-		"push": func() (cli.Command, error) {
-			return &command.PushCommand{
+		"plugin": func() (cli.Command, error) {
+			return &command.PluginCommand{
 				Meta: *CommandMeta,
 			}, nil
 		},
@@ -50,17 +70,8 @@ func init() {
 
 		"version": func() (cli.Command, error) {
 			return &command.VersionCommand{
-				Meta:              *CommandMeta,
-				Revision:          version.GitCommit,
-				Version:           version.Version,
-				VersionPrerelease: version.VersionPrerelease,
-				CheckFunc:         commandVersionCheck,
-			}, nil
-		},
-
-		"plugin": func() (cli.Command, error) {
-			return &command.PluginCommand{
-				Meta: *CommandMeta,
+				Meta:      *CommandMeta,
+				CheckFunc: commandVersionCheck,
 			}, nil
 		},
 	}
