@@ -5,20 +5,18 @@ import (
 	"log"
 	"os"
 	"path/filepath"
+	"sort"
 	"time"
 
 	checkpoint "github.com/hashicorp/go-checkpoint"
+	"github.com/hashicorp/packer-plugin-sdk/pathing"
 	packerVersion "github.com/hashicorp/packer/version"
 )
 
-const TelemetryVersion string = "beta/packer/4"
+const TelemetryVersion string = "beta/packer/5"
 const TelemetryPanicVersion string = "beta/packer_panic/4"
 
-var CheckpointReporter CheckpointTelemetry
-
-func init() {
-	CheckpointReporter.startTime = time.Now().UTC()
-}
+var CheckpointReporter *CheckpointTelemetry
 
 type PackerReport struct {
 	Spans    []*TelemetrySpan `json:"spans"`
@@ -28,17 +26,20 @@ type PackerReport struct {
 }
 
 type CheckpointTelemetry struct {
-	enabled       bool
 	spans         []*TelemetrySpan
 	signatureFile string
 	startTime     time.Time
 }
 
-func (c *CheckpointTelemetry) Enable(disableSignature bool) {
-	configDir, err := ConfigDir()
+func NewCheckpointReporter(disableSignature bool) *CheckpointTelemetry {
+	if disabled := os.Getenv("CHECKPOINT_DISABLE"); disabled != "" {
+		return nil
+	}
+
+	configDir, err := pathing.ConfigDir()
 	if err != nil {
 		log.Printf("[WARN] (telemetry) setup error: %s", err)
-		return
+		return nil
 	}
 
 	signatureFile := ""
@@ -48,8 +49,10 @@ func (c *CheckpointTelemetry) Enable(disableSignature bool) {
 		signatureFile = filepath.Join(configDir, "checkpoint_signature")
 	}
 
-	c.signatureFile = signatureFile
-	c.enabled = true
+	return &CheckpointTelemetry{
+		signatureFile: signatureFile,
+		startTime:     time.Now().UTC(),
+	}
 }
 
 func (c *CheckpointTelemetry) baseParams(prefix string) *checkpoint.ReportParams {
@@ -69,7 +72,7 @@ func (c *CheckpointTelemetry) baseParams(prefix string) *checkpoint.ReportParams
 }
 
 func (c *CheckpointTelemetry) ReportPanic(m string) error {
-	if !c.enabled {
+	if c == nil {
 		return nil
 	}
 	panicParams := c.baseParams(TelemetryPanicVersion)
@@ -84,19 +87,24 @@ func (c *CheckpointTelemetry) ReportPanic(m string) error {
 	return checkpoint.Report(ctx, panicParams)
 }
 
-func (c *CheckpointTelemetry) AddSpan(name, pluginType string) *TelemetrySpan {
+func (c *CheckpointTelemetry) AddSpan(name, pluginType string, options interface{}) *TelemetrySpan {
+	if c == nil {
+		return nil
+	}
 	log.Printf("[INFO] (telemetry) Starting %s %s", pluginType, name)
+
 	ts := &TelemetrySpan{
 		Name:      name,
-		Type:      pluginType,
+		Options:   flattenConfigKeys(options),
 		StartTime: time.Now().UTC(),
+		Type:      pluginType,
 	}
 	c.spans = append(c.spans, ts)
 	return ts
 }
 
 func (c *CheckpointTelemetry) Finalize(command string, errCode int, err error) error {
-	if !c.enabled {
+	if c == nil {
 		return nil
 	}
 
@@ -112,26 +120,56 @@ func (c *CheckpointTelemetry) Finalize(command string, errCode int, err error) e
 		extra.Error = err.Error()
 	}
 	params.Payload = extra
+	// b, _ := json.MarshalIndent(params, "", "    ")
+	// log.Println(string(b))
 
-	ctx, cancel := context.WithTimeout(context.Background(), 750*time.Millisecond)
+	ctx, cancel := context.WithTimeout(context.Background(), 2*time.Second)
 	defer cancel()
 
+	log.Printf("[INFO] (telemetry) Finalizing.")
 	return checkpoint.Report(ctx, params)
 }
 
 type TelemetrySpan struct {
-	Name      string    `json:"name"`
-	Type      string    `json:"type"`
-	StartTime time.Time `json:"start_time"`
 	EndTime   time.Time `json:"end_time"`
 	Error     string    `json:"error"`
+	Name      string    `json:"name"`
+	Options   []string  `json:"options"`
+	StartTime time.Time `json:"start_time"`
+	Type      string    `json:"type"`
 }
 
 func (s *TelemetrySpan) End(err error) {
+	if s == nil {
+		return
+	}
 	s.EndTime = time.Now().UTC()
 	log.Printf("[INFO] (telemetry) ending %s", s.Name)
 	if err != nil {
 		s.Error = err.Error()
-		log.Printf("[INFO] (telemetry) found error: %s", err.Error())
 	}
 }
+
+func flattenConfigKeys(options interface{}) []string {
+	var flatten func(string, interface{}) []string
+
+	flatten = func(prefix string, options interface{}) (strOpts []string) {
+		if m, ok := options.(map[string]interface{}); ok {
+			for k, v := range m {
+				if prefix != "" {
+					k = prefix + "/" + k
+				}
+				if n, ok := v.(map[string]interface{}); ok {
+					strOpts = append(strOpts, flatten(k, n)...)
+				} else {
+					strOpts = append(strOpts, k)
+				}
+			}
+		}
+		return
+	}
+
+	flattened := flatten("", options)
+	sort.Strings(flattened)
+	return flattened
+}
