@@ -78,9 +78,10 @@ type Config struct {
 
 	remoteCleanUpScriptPath string
 
-	// If set, sets PowerShell's [PSDebug mode](https://docs.microsoft.com/en-us/powershell/module/microsoft.powershell.core/set-psdebug?view=powershell-7)
-	//  in order to make script debugging easier. For instance, setting the
-	//    value to 1 results in adding this to the execute command:
+	// If set, sets PowerShell's [PSDebug mode
+	// on](https://docs.microsoft.com/en-us/powershell/module/microsoft.powershell.core/set-psdebug?view=powershell-7)
+	// in order to make script debugging easier. For instance, setting the value
+	// to 1 results in adding this to the execute command:
 	//
 	//    ``` powershell
 	//    Set-PSDebug -Trace 1
@@ -285,9 +286,9 @@ func (p *Provisioner) Provision(ctx context.Context, ui packersdk.Ui, comm packe
 		if err != nil {
 			return fmt.Errorf("Error stating powershell script: %s", err)
 		}
-		if strings.HasSuffix(p.config.RemotePath, `\`) {
+		if os.IsPathSeparator(p.config.RemotePath[len(p.config.RemotePath)-1]) {
 			// path is a directory
-			p.config.RemotePath += filepath.Base((fi).Name())
+			p.config.RemotePath += filepath.Base(fi.Name())
 		}
 		f, err := os.Open(path)
 		if err != nil {
