@@ -10,6 +10,11 @@ export default [
     url: '/docs',
     type: 'inbound',
   },
+  {
+    text: 'Plugins',
+    url: '/plugins',
+    type: 'inbound',
+  },
   {
     text: 'Community',
     url: '/community',
